"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const BaseCommand_1 = require("../../application/BaseCommand");
const fs_extra_1 = require("fs-extra");
class MakeDocumentation extends BaseCommand_1.default {
    constructor() {
        super(...arguments);
        this.signature = 'make:documentation';
        this.configKey = 'documentation';
    }
    async run() {
        this.logger.comet('Generating API documentation...');
        const { args, flags } = this.parse(MakeDocumentation);
        const file = await this.loadFile(args);
        if (flags.output) {
            this.configRepository.set(`plugins.${this.configKey}.output`, flags.output);
        }
        const specification = await this.parseSpec(file);
        await this.execute(specification);
    }
    async execute(specification) {
        await fs_extra_1.writeFile('./result.json', JSON.stringify(specification, null, 2));
        await this.runPlugins(specification);
    }
}
exports.default = MakeDocumentation;
MakeDocumentation.description = 'Parse an API specification, and automatically generate API documentation';
MakeDocumentation.examples = [
    '$ comet make:documentation api.json',
];
MakeDocumentation.args = [
    {
        name: 'input',
        required: true,
        description: 'relative or absolute path to the input file (your API specification)',
    },
];
MakeDocumentation.flags = {
    help: command_1.flags.help({ char: 'h' }),
    output: command_1.flags.string({
        char: 'o',
    }),
};
//# sourceMappingURL=documentation.js.map