"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const BaseCommand_1 = require("../../application/BaseCommand");
class MakePostman extends BaseCommand_1.default {
    constructor() {
        super(...arguments);
        this.signature = 'make:postman';
        this.configKey = 'make.postman';
    }
    async run() {
        this.logger.comet('Generating Postman Collection...');
        const { args, flags } = this.parse(MakePostman);
        const file = await this.loadFile(args);
        if (flags.output) {
            this.configRepository.set(`commands.${this.configKey}.output`, flags.output);
        }
        const specification = await this.parseSpec(file);
        await this.execute(specification);
    }
    async execute(specification) {
        await this.runPlugins(specification);
    }
}
exports.default = MakePostman;
MakePostman.description = 'Parse an API specification, and automatically generate Postman collection';
MakePostman.examples = [
    '$ comet make:postman api.json',
];
MakePostman.args = [
    {
        name: 'input',
        required: true,
        description: 'relative or absolute path to the input file (your API specification)',
    },
];
MakePostman.flags = {
    help: command_1.flags.help({ char: 'h' }),
    output: command_1.flags.string({
        char: 'o',
    }),
};
//# sourceMappingURL=postman.js.map