"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const BaseCommand_1 = require("../../application/BaseCommand");
class MakeTests extends BaseCommand_1.default {
    constructor() {
        super(...arguments);
        this.signature = 'make:tests';
        this.configKey = 'make.tests';
    }
    async run() {
        this.logger.comet('Generating test cases...');
        const { args, flags } = this.parse(MakeTests);
        const file = await this.loadFile(args);
        if (flags.output) {
            this.configRepository.set(`commands.${this.configKey}.output`, flags.output);
        }
        const specification = await this.parseSpec(file);
        await this.execute(specification);
    }
    async execute(specification) {
        this.logger.spin('Creating test case definitions...');
        await this.runPlugins(specification);
        this.logger.succeed('Test cases created');
        this.printWarnings();
    }
}
exports.default = MakeTests;
MakeTests.description = 'Parse an API specification, and automatically generate integration tests';
MakeTests.examples = [
    '$ comet make:tests api.json',
];
MakeTests.args = [
    {
        name: 'input',
        required: true,
        description: 'relative or absolute path to the input file (your API specification)',
    },
];
MakeTests.flags = {
    help: command_1.flags.help({ char: 'h' }),
    output: command_1.flags.string({
        char: 'o',
    }),
};
//# sourceMappingURL=tests.js.map