"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
class Resolver {
    constructor(config, signature) {
        this.config = config;
        this.signature = signature.replace(':', '.');
        this.command = signature;
    }
    async resolveAdapter(detected) {
        const configuredAdapter = this.config.get(`commands.${this.signature}.adapter`);
        if (configuredAdapter == null && detected === null) {
            throw new Error(`ConfigError:
      No adapter configuration could be found for \`${this.command}\`.
      Please check your configuration file, and make sure that a value has been
      defined for \`${this.signature}.adapter\`
      `);
        }
        const adapter = configuredAdapter || detected;
        try {
            const adapterClass = await Promise.resolve().then(() => require(String(adapter)));
            return new adapterClass();
        }
        catch (error) {
            error.message =
                `Could not find module \`${adapter}\`. Run \`npm install ${adapter}\` to install`;
            throw error;
        }
    }
    async resolvePlugins() {
        const configuredPlugins = this.config.get(`commands.${this.signature}.plugins`);
        if (configuredPlugins == null) {
            throw new Error(`ConfigError:
      No resolvable plugin configuration could be found for \`${this.command}\`.
      Please check your configuration file, and make sure that a value has been
      defined for \`${this.signature}.plugins\`
      `);
        }
        if (Array.isArray(configuredPlugins) === false) {
            throw new Error(`ConfigError:
      The plugin configuration for \`${this.command}\` is not a valid array. Please make
      sure your configuration is correct
      `);
        }
        const pluginClasses = [];
        for (const plugin of configuredPlugins) {
            try {
                const pluginClass = await Promise.resolve().then(() => require(plugin));
                pluginClasses.push(new pluginClass());
            }
            catch (error) {
                error.message =
                    `Could not find module \`${plugin}\`. Run \`npm install ${plugin}\` to install\n${error.message}`;
                throw error;
            }
        }
        return pluginClasses;
    }
}
exports.default = Resolver;
//# sourceMappingURL=Resolver.js.map